<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="gl_ES">
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="42"/>
        <source>License</source>
        <translation>Licenza</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="43"/>
        <location filename="../about.cpp" line="53"/>
        <source>Changelog</source>
        <translation>Rexistro dos cambios</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="44"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="64"/>
        <source>&amp;Close</source>
        <translation>&amp;Cerrar</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="55"/>
        <source>GUI for applying assorted useful tweaks</source>
        <translation>GUI para aplicar diversas melloras útiles</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>launches brightness-systray</source>
        <translation>lanza brightness-systray</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="59"/>
        <source>opens with display tab open.  Only valid with Xfce desktop running</source>
        <translation>abre co separador de visualización aberto. Só válido cun escritorio Xfce en execución</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="60"/>
        <source>Opens theme tab directly.  Valid on Xfce &amp; Fluxbox desktops</source>
        <translation>Abre a lapela do tema directamente. Válido nos escritorios Xfce e Fluxbox</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="61"/>
        <source>Display additional debug output in console</source>
        <translation>Mostra a saída de depuración adicional na consola</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="62"/>
        <source>Opens Other tab directly.  Valid on all desktops</source>
        <translation>Abre directamente outra guía. Válido en todos os escritorios</translation>
    </message>
</context>
<context>
    <name>Tweak</name>
    <message>
        <location filename="../tweak.ui" line="14"/>
        <location filename="../tweak.cpp" line="71"/>
        <location filename="../tweak.cpp" line="242"/>
        <location filename="../tweak.cpp" line="261"/>
        <source>MX Tweak</source>
        <translation>MX axustes rápidos</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="33"/>
        <source>Xfce Panel</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="39"/>
        <location filename="../tweak.ui" line="233"/>
        <location filename="../tweak.ui" line="520"/>
        <location filename="../tweak.ui" line="599"/>
        <location filename="../tweak.ui" line="655"/>
        <location filename="../tweak.ui" line="682"/>
        <location filename="../tweak.ui" line="874"/>
        <location filename="../tweak.ui" line="1265"/>
        <location filename="../tweak.ui" line="1394"/>
        <location filename="../tweak.ui" line="1441"/>
        <location filename="../tweak.ui" line="1532"/>
        <source>Apply</source>
        <extracomment>apply changes</extracomment>
        <translation>Aplicar</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="58"/>
        <source>Tasklist</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="64"/>
        <source>Set Tasklist plugin to:</source>
        <translation>Configura o plugin Tasklist para:</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="71"/>
        <source>Docklike is the modern dock plugin for the panel. Window Buttons is the classic tasklist without dock features.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="78"/>
        <source>Tasklist Options</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="85"/>
        <source>Docklike Options</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="95"/>
        <source>Affects 1st Panel</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="101"/>
        <location filename="../tweak.ui" line="1048"/>
        <location filename="../tweak.ui" line="1158"/>
        <location filename="../tweak.ui" line="1285"/>
        <source>Placement</source>
        <translation>Posicionamento</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="114"/>
        <source>Backup/Restore Configuration (all panels)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="127"/>
        <source>Backup current panel configuration</source>
        <translation>Gardar a configuración actual do panel</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="141"/>
        <source>Restore selected panel configuration</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="148"/>
        <source>Restore default panel</source>
        <translation>Restaurar o panel predeterminado</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="158"/>
        <source>Panel Plugin Scales</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="164"/>
        <source>Volume</source>
        <extracomment>volume plugin scale factor</extracomment>
        <translation>Volume</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="184"/>
        <source>Power Manager</source>
        <extracomment>power manager plugin scale factor</extracomment>
        <translation>Xestor de energia</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="221"/>
        <source>Theme</source>
        <translation>Tema</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="227"/>
        <source>Theme Options</source>
        <translation>Opcións de tema</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="262"/>
        <source>Remove User Theme Set</source>
        <translation>Eliminar tema do usuario</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="275"/>
        <source>Themes</source>
        <translation>Temas</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="281"/>
        <source>Application</source>
        <extracomment>theme an application will get</extracomment>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="301"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Toggle Dark Mode for GTK4 libadwaita applications&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="304"/>
        <source>Dark Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="311"/>
        <location filename="../tweak.ui" line="1778"/>
        <source>Window Manager</source>
        <extracomment>theme a window manager border will get</extracomment>
        <translation>Xestor de lapelas</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="331"/>
        <source>Legacy Styles</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="344"/>
        <source>Icons</source>
        <extracomment>icon theme</extracomment>
        <translation>Iconas</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="351"/>
        <source>Cursors</source>
        <extracomment>cursor theme</extracomment>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="358"/>
        <source>Save Current Settings as a Theme Set</source>
        <extracomment>save theme settings as a group</extracomment>
        <translation>Gardar as configuracións actuais como tema</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="368"/>
        <source>Size</source>
        <extracomment>size of the cursor</extracomment>
        <translation>Tamaño</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="378"/>
        <source>default</source>
        <extracomment>default cursor size determined by X server</extracomment>
        <translation>predeterminado</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="401"/>
        <location filename="../tweak.ui" line="453"/>
        <source>Compositor</source>
        <translation>Compositor</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="413"/>
        <source>Changing the VBlank mode may help alleviate some screen tearing issues. See Help for more information.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="416"/>
        <source>VBlank</source>
        <translation>VBlank</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="424"/>
        <source>auto</source>
        <translation>automático</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="429"/>
        <source>glx</source>
        <translation>glx</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="434"/>
        <source>xpresent</source>
        <translation>xpresent</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="439"/>
        <location filename="../tweak.ui" line="1022"/>
        <source>off</source>
        <extracomment>setting to 0 turns off screensaver screen blank</extracomment>
        <translation>apagado</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="447"/>
        <source>Transparency and shadow options</source>
        <translation>Opcións de transparencia e sombreado</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="463"/>
        <source>Xfce Compositor Settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="466"/>
        <source>Xfwm Settings</source>
        <translation>Configuración do Xfwm</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="476"/>
        <source>Launch compton-conf configuration tool</source>
        <translation>Executar a ferramenta de configuración compton-conf</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="479"/>
        <source>Picom settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="490"/>
        <source>Edit compton.conf directly in text editor</source>
        <translation>Editar o ficheiro compton.conf directamente no editor de texto</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="493"/>
        <source>Edit picom.conf</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="540"/>
        <source>Display</source>
        <translation>Display</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="546"/>
        <source>Display Tweaks</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="552"/>
        <source>Hardware Backlight</source>
        <extracomment>set the hardware backlight on monitors that have them</extracomment>
        <translation>Retroiluminación da pantalla</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="575"/>
        <location filename="../tweak.ui" line="706"/>
        <source>TextLabel</source>
        <translation>Rótulo de texto</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="582"/>
        <source>GTK scaling</source>
        <extracomment>gtk scale factor</extracomment>
        <translation>Escala GTK</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="635"/>
        <source>Choose Display for xrandr tweaks</source>
        <extracomment>choose the display that the xrandr tweaks will be acted upon</extracomment>
        <translation>Escoller pantalla para axustes do xrandr</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="645"/>
        <source>Resolution</source>
        <translation>Resolución</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="662"/>
        <source>xrandr Scaling</source>
        <extracomment>xrandr scale factor</extracomment>
        <translation>Escala xrandr</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="689"/>
        <source>Software (xrandr) Brightness</source>
        <extracomment>adjust brightness (not backlight) via software</extracomment>
        <translation>Brillo controlado polo software (xrandr)</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="713"/>
        <source>Saving is per display</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="716"/>
        <source>Save</source>
        <translation>Gardar</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="740"/>
        <source>Xfce</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="746"/>
        <source>Desktop</source>
        <translation>Escritorio</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="752"/>
        <source>Enable single-click on desktop</source>
        <translation>Acivar premer único</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="759"/>
        <source>Enable Desktop Zoom </source>
        <translation>Activa a ampliación do escritorio</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="766"/>
        <location filename="../tweak.ui" line="1355"/>
        <source>Show windows from all workspaces in panel</source>
        <translation>Amosar as lapelas de todas asáreas de traballo no panel</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="773"/>
        <source>Do not shorten file names on the desktop</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="783"/>
        <source>Thunar</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="789"/>
        <source>Enable single-click in Thunar File Manager</source>
        <translation>Activar cun premer no xestor de ficheiros Thumar</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="796"/>
        <source>Reset custom right-click actions to system defaults</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="803"/>
        <source>Thunar windows always open in split view</source>
        <translation>As xanelas do Thunar sempre abren en vista dividida</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="810"/>
        <source>Thunar split view opens horizontal</source>
        <translation>A vista dividida do Thunar abre en horizontal</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="820"/>
        <source>Show percentages in notifcations when available</source>
        <translation>Mostrar porcentaxes nas notificacións cando estean dispoñibles</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="827"/>
        <source>Show GTK File Dialog action buttons at bottom of dialogs</source>
        <translation>Mostrar botóns de acción do diálogo de ficheiros GTK na parte inferior dos diálogos</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="834"/>
        <source>(also turns off Client Side Decorations for Xfce applications)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="844"/>
        <source>Enable hibernate on Log Out menu </source>
        <translation>Activar &apos;Hibernar&apos; no menú Saír</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="851"/>
        <source>note: to hibernate, swap needs to be &gt;= RAM</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="885"/>
        <source>Fluxbox</source>
        <translation>Fluxbox</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="891"/>
        <location filename="../tweak.ui" line="1365"/>
        <source>Reset Defaults</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="897"/>
        <source>Reset DefaultDock</source>
        <translation>Restablecer a dock predeterminada</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="904"/>
        <source>Reset Fluxbox Menu</source>
        <translation>Restablecer o menú do Fluxbox</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="911"/>
        <source>Reset ALL mx-fluxbox settings</source>
        <translation>Restablecer todas as configuracións do mx-fluxbox</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="918"/>
        <source>Add new default menu items, if any, to existing fluxbox menu.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="921"/>
        <source>Upgrade existing menu entries</source>
        <translation>Actualizar entradas de menú existentes</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="931"/>
        <source>Desktop Icons</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="937"/>
        <source>Toggle desktop icons</source>
        <translation>Activa ou desactiva as iconas do escritorio</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="945"/>
        <location filename="../tweak.ui" line="969"/>
        <source>On</source>
        <translation>Amosar</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="950"/>
        <location filename="../tweak.ui" line="974"/>
        <source>Off</source>
        <translation>Agochar</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="958"/>
        <source>Toggle icon captions</source>
        <translation>Alterna os subtítulos das iconas</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="979"/>
        <source>On Hover</source>
        <translation>Ao apuntar</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1006"/>
        <source>Screensaver</source>
        <translation>Protección da pantalla</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1012"/>
        <source>Idle time (minutes)</source>
        <extracomment>set the time of inactivity  before screensaver screen blank occurs</extracomment>
        <translation>Tempo de inactividade (minutos)</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1035"/>
        <source>Toolbar Settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1041"/>
        <source>Height</source>
        <translation>Altura</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1122"/>
        <location filename="../tweak.ui" line="1232"/>
        <source>Autohide</source>
        <translation>Agochar automático</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1129"/>
        <source>Show Toolbar</source>
        <translation>Mostrar a barra de ferramentas</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1136"/>
        <source>Width</source>
        <translation>Largura</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1152"/>
        <source>Dock Settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1239"/>
        <source>Manage Tint2 Panel</source>
        <translation>Xestionar o panel Tint2</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1273"/>
        <source>Plasma</source>
        <translation>Plasma</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1279"/>
        <source>Affects 1st panel</source>
        <translation>Afecta ao panel 1</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1296"/>
        <source>Bottom</source>
        <translation>Abaixo</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1301"/>
        <source>Left</source>
        <translation>Á esquerda</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1306"/>
        <source>Top</source>
        <translation>Arriba</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1311"/>
        <source>Right</source>
        <translation>Á dereita</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1335"/>
        <source>Workspace</source>
        <translation>Escritorio</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1341"/>
        <source>Autostart plasma-discover system tray update notification utility</source>
        <extracomment>enable or disable autostartup of plasma-discover updater utility on login</extracomment>
        <translation>Inicio automático de notificación de actualización da bandexa do sistema plasma-discover</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1348"/>
        <source>Enable single-click</source>
        <translation>Acivar premer único</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1371"/>
        <source>Reset KDE/Plasma defaults</source>
        <translation>Restablcer as predeterminadas do KDE/Plasma</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1405"/>
        <source>Super Key</source>
        <extracomment>referring to the meta or Left Super Key</extracomment>
        <translation>Tecla Super</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1411"/>
        <source>Also known as the &quot;windows&quot; key</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1414"/>
        <source>Command to run with Super (Meta) key</source>
        <extracomment>label for the field to enter the command to use with super key</extracomment>
        <translation>Comando para executar coa tecla Super (Meta)</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1424"/>
        <source>xfce-superkey defaults</source>
        <extracomment>indicates that xfce-superkey will select a command by its default logic</extracomment>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1431"/>
        <source>Choose application</source>
        <extracomment>description of button action to launch file dialog to choose an application</extracomment>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1462"/>
        <source>Miscellaneous</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1518"/>
        <source>Reset Lightdm (login screen) to system default theme</source>
        <translation>Restablecer o tema predeterminado da pantalla da entrada (LightDM)</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1623"/>
        <source>Enable mounting of internal drives by non-root users</source>
        <translation>Activar o conexión de discos internos por usuarios alén do root</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1616"/>
        <source>Enable kernel sandbox</source>
        <translation>Activar ambiente illado para o núcleo</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1566"/>
        <source>requires reboot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1569"/>
        <source>Enable Bluetooth adapters on boot</source>
        <translation>Habilitar adaptadores Bluetooth ao arrancar</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1694"/>
        <source>Enable Bluetooth battery info for connected devices (requires system restart)</source>
        <extracomment>expose battery info for connected bluetooth devices to the operating system via dbus</extracomment>
        <translation>Activar a información da batería de Bluetooth para os dispositivos conectados (require o reinicio do sistema)</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1491"/>
        <source>Early loading of KVM module is new to  kernel 6.12 and conflicts with some non-KVM virtual machine applications, including virtualbox</source>
        <extracomment>early loading is new on 6.12 kernel and conflicts with virtualbox</extracomment>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1494"/>
        <source>Disable early KVM module load (must be disabled for Virtualbox operation on kernel 6.12 and up)</source>
        <extracomment>disable early loading of KVM module.  necessary for virtualbox to function with kernels 6.12 and up.  actually default behavior on kernels 6.11 and earlier.</extracomment>
        <translation>Desactivar a carga inicial do módulo KVM (debe estar desactivado para o funcionamento de Virtualbox no kernel 6.12 ou superior)</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1630"/>
        <source>Apt installs additional &quot;recommends&quot; packages as dependencies</source>
        <translation>Apt instala paquetes &quot;recomendados&quot; adicionales como dependencias</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1576"/>
        <source>Generate fluxbox All Apps menu after package installation, removal, and updates</source>
        <translation>Xerar menú Todas as Aplicacións de fluxbox despois da instalación, eliminación e actualización de paquetes.</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1609"/>
        <source>Use Client Side Decorations (CSD) on GTK3 applications that support them (requires session restart)</source>
        <translation>Usa as decoracións do lado do cliente (CSD) en aplicativos GTK3 que as admitan (require reinicio da sesión)</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1508"/>
        <source>put a hold or remove a hold on updates of Liquorix kernels</source>
        <extracomment>toggle for apt hold action on update meta packages</extracomment>
        <translation>poñer unha retención ou eliminar unha retención nas actualizacións dos Kernels de Liquorix</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1511"/>
        <source>Enable Automatic Liquorix Kernel Updates (MX ahs repository)</source>
        <extracomment>uses apt-mark to hold or unhold updates to kernel metapackages</extracomment>
        <translation>Habilitar Actualizacións Automáticas do Kernel Liquorix (repositorio MX ahs)</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1684"/>
        <source>put a hold or remove a hold on updates of Debian  kernels</source>
        <extracomment>toggle for apt hold action on update meta packages</extracomment>
        <translation>poñer unha retención ou eliminar unha retención nas actualizacións dos kernels de Debian</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1687"/>
        <source>Enable Automatic Debian Kernel Updates</source>
        <extracomment>uses apt-mark to hold or unhold updates to kernel metapackages</extracomment>
        <translation>Habilitar actualizacións automáticas do kernel Debian</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1637"/>
        <source>Use intel driver instead of default &quot;modesetting&quot; driver (requires restart)</source>
        <translation>Usar o controlador Intel en vez do controlador &quot;modesetting&quot; predeterminado (require reiniciar)</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1471"/>
        <source>NOTE: existing /etc/X11/xorg.conf.d/20-intel.conf will be backed up to home folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1583"/>
        <source>Use tearfree amdgpu option</source>
        <translation>Usar a opción anti-distorsión do controlador amdgpu</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1545"/>
        <source>NOTE: existing /etc/X11/xorg.conf.d/20-amd.conf will be backed up to home folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1525"/>
        <source>Use tearfree radeon driver option</source>
        <translation>Usar a opción anti-distorsión do controlador radeon</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1501"/>
        <source>NOTE: existing /etc/X11/xorg.conf.d/20-radeon.conf will be backed up to home folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1559"/>
        <source>Change computer name (requires reboot)</source>
        <extracomment>option to change the system hostname, requires a reboot to be 100% effective</extracomment>
        <translation>Cambiar o nome do ordenador (require reiniciar)</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1552"/>
        <source>Change Default Display Manager (login screen) (requires reboot)</source>
        <extracomment>option to change display manager login screen.  present if more than one display manager is installed</extracomment>
        <translation>Cambiar o Xestor de Visualización predeterminado (pantalla de inicio de sesión) (require reinicio)</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1647"/>
        <source>Password for administrative tasks:</source>
        <translation>Contrasinal para tarefas administrativas:</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1654"/>
        <source>&amp;User</source>
        <translation>&amp;Usuari</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1661"/>
        <source>Root</source>
        <translation>Root</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1701"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Init system that is used as the default on the main grub boot menu entry&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1704"/>
        <source>Change Default Init System</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1729"/>
        <source>Xfce Settings</source>
        <translation>Configuración do Xfce</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1735"/>
        <source>Customize the panel</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1745"/>
        <source>Panel</source>
        <translation>Panel</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1765"/>
        <source>Configure window behavior and shortcuts</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1798"/>
        <source>Customize the look of your desktop</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak.ui" line="1811"/>
        <source>Appearance</source>
        <translation>Apariencia</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1823"/>
        <source>About</source>
        <translation>Sobre</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1833"/>
        <source>Help</source>
        <translation>Axuda</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1891"/>
        <source>Quit application</source>
        <translation>Saír do aplicativo</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1894"/>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1900"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../tweak.cpp" line="72"/>
        <source>--display switch only valid for Xfce</source>
        <translation>-cambio na pantalla válido só para o Xfce</translation>
    </message>
    <message>
        <location filename="../tweak.cpp" line="241"/>
        <source>About MX Tweak</source>
        <translation>Sobre MX Axustes Rápidos</translation>
    </message>
    <message>
        <location filename="../tweak.cpp" line="243"/>
        <source>Version: </source>
        <translation>Versión: </translation>
    </message>
    <message>
        <location filename="../tweak.cpp" line="244"/>
        <source>App for quick default ui theme changes and tweaks</source>
        <translation>Aplicativo para rapidamente facer cambios ao tema predeterminado da interface de usuario e outros axustes</translation>
    </message>
    <message>
        <location filename="../tweak.cpp" line="246"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../tweak.cpp" line="247"/>
        <source>%1 License</source>
        <translation>Licenza de %1</translation>
    </message>
    <message>
        <location filename="../tweak.cpp" line="261"/>
        <source>%1 Help</source>
        <translation>Axuda para %1</translation>
    </message>
</context>
<context>
    <name>TweakCompositor</name>
    <message>
        <location filename="../tweak_compositor.cpp" line="62"/>
        <source>None</source>
        <translation>Ningún</translation>
    </message>
    <message>
        <location filename="../tweak_compositor.cpp" line="63"/>
        <source>Xfwm (Xfce) Compositor</source>
        <translation>Compositoir do Xfwm (Xfce)</translation>
    </message>
    <message>
        <location filename="../tweak_compositor.cpp" line="64"/>
        <source>Picom</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TweakMisc</name>
    <message>
        <location filename="../tweak_misc.cpp" line="305"/>
        <source>Please enter a computer name.</source>
        <comment>question to enter a name for the computer hostname</comment>
        <translation>Inserir un nome do computador.</translation>
    </message>
    <message>
        <location filename="../tweak_misc.cpp" line="309"/>
        <source>Sorry, your computer name contains invalid characters.
You'll have to select a different
name before proceeding.</source>
        <comment>unacceptable characters are found in hostname, pick a new name</comment>
        <translation>O nome do computador contén caracteres inválidos. Ten que ser escollido un nome diferente antes de proseguir.</translation>
    </message>
</context>
<context>
    <name>TweakSuperKey</name>
    <message>
        <location filename="../tweak_superkey.cpp" line="43"/>
        <source>Select application to run</source>
        <comment>will show in file dialog when selection an application to run</comment>
        <translation>Selecciona a aplicación para executar</translation>
    </message>
</context>
<context>
    <name>TweakTheme</name>
    <message>
        <location filename="../tweak_theme.cpp" line="64"/>
        <source>Plasma Widget Themes</source>
        <comment>theme style of the kde plasma widgets</comment>
        <translation>Temas de widgets de plasma</translation>
    </message>
    <message>
        <location filename="../tweak_theme.cpp" line="65"/>
        <source>Color Schemes</source>
        <comment>plasma widget color schemes</comment>
        <translation>Esquemas de cores</translation>
    </message>
    <message>
        <location filename="../tweak_theme.cpp" line="66"/>
        <source>Plasma Look &amp; Feel Global Themes</source>
        <comment>plasma global themes</comment>
        <translation>Temas globais de aspecto e sensación de plasma</translation>
    </message>
    <message>
        <location filename="../tweak_theme.cpp" line="139"/>
        <source>Choose a theme set</source>
        <translation>Elixe un tema</translation>
    </message>
</context>
<context>
    <name>TweakXfcePanel</name>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="17"/>
        <source>Horizontal (Bottom)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="18"/>
        <source>Horizontal (Top)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="20"/>
        <source>Vertical (Left)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="21"/>
        <source>Vertical (Right)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="23"/>
        <source>docklike</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="24"/>
        <source>Window Buttons</source>
        <translation>Botóns de lapela</translation>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="273"/>
        <location filename="../tweak_xfce_panel.cpp" line="280"/>
        <location filename="../tweak_xfce_panel.cpp" line="297"/>
        <location filename="../tweak_xfce_panel.cpp" line="301"/>
        <source>MX Tweak</source>
        <translation>MX axustes rápidos</translation>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="274"/>
        <source>Plese remove special characters</source>
        <translation>Por favor, elimina os caracteres especiais</translation>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="274"/>
        <source>from file name</source>
        <translation>do nome do ficheiro</translation>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="280"/>
        <source>File name already exists.  Choose another name</source>
        <translation>O nome do ficheiro xa existe. Escolle outro nome</translation>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="298"/>
        <source>File is not a valid tar.xz archive file</source>
        <translation>O ficheiro non é un ficheiro de arquivo tar.xz válido</translation>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="302"/>
        <source>Archive does not contain a panel config</source>
        <translation>O arquivo non contén unha configuración de panel</translation>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="733"/>
        <source>Panel Preferences</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>brightness_small</name>
    <message>
        <location filename="../brightness_small.ui" line="14"/>
        <source>MainWindow</source>
        <translation>Lapela principal</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="34"/>
        <source>&gt;&gt;</source>
        <translation>&gt;&gt;</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="41"/>
        <source>Software (xrandr) Brightness</source>
        <translation>Brillo controlado polo software (xrandr)</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="61"/>
        <location filename="../brightness_small.ui" line="89"/>
        <source>TextLabel</source>
        <translation>Rótulo de texto</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="68"/>
        <source>Save</source>
        <translation>Gardar</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="75"/>
        <source>Hardware Backlight</source>
        <translation>Retroiluminación da pantalla</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="35"/>
        <source>Brightness</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="54"/>
        <source>Display</source>
        <translation>Amosar</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="59"/>
        <source>&amp;Quit</source>
        <translation>&amp;Saír</translation>
    </message>
</context>
<context>
    <name>remove_user_theme_set</name>
    <message>
        <location filename="../remove_user_theme_set.ui" line="14"/>
        <source>Remove User Theme Set</source>
        <translation>Eliminar tema do usuario</translation>
    </message>
</context>
<context>
    <name>theming_to_tweak</name>
    <message>
        <location filename="../theming_to_tweak.ui" line="14"/>
        <source>New Theme Set</source>
        <translation>Novo tema establecido</translation>
    </message>
    <message>
        <location filename="../theming_to_tweak.ui" line="20"/>
        <source>Enter name for new theme set</source>
        <translation>Inserir o nome do tema novo establecido</translation>
    </message>
</context>
<context>
    <name>window_buttons</name>
    <message>
        <location filename="../window_buttons.ui" line="14"/>
        <location filename="../window_buttons.cpp" line="38"/>
        <source>Window Buttons</source>
        <translation>Botóns de lapela</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="23"/>
        <source>Appearance</source>
        <translation>Apariencia</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="29"/>
        <source>Show button labels</source>
        <translation>Amosar rótulos dos botóns</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="36"/>
        <source>Show flat buttons</source>
        <translation>Amosar botóns sen relevo</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="43"/>
        <source>Show handle</source>
        <translation>Amosar o manexo</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="50"/>
        <source>Sorting Order:</source>
        <translation>Ordenación:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="58"/>
        <source>Timestamp</source>
        <translation>Estampa de data/hora</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="63"/>
        <source>Group title and timestamp</source>
        <translation>Título do grupo e estampa de data/hora</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="68"/>
        <source>Window Title</source>
        <translation>Título da lapela</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="73"/>
        <source>Group title and window title</source>
        <translation>Título do grupo e título da lapela</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="78"/>
        <source>None, allow drag-and-drop</source>
        <translation>Ningún; permitir arrastrar-e-deixar caer</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="89"/>
        <source>Behavior</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="95"/>
        <source>Window grouping:</source>
        <translation>Agrupamento de lapelas:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="103"/>
        <source>Never</source>
        <translation>Nunca</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="108"/>
        <source>Always</source>
        <translation>Sempre</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="116"/>
        <source>Middle click action:</source>
        <translation>Acción do botón central:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="124"/>
        <source>Nothing</source>
        <translation>Sen acción</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="129"/>
        <source>Close window</source>
        <translation>Pechar lapela</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="134"/>
        <source>Minimize window</source>
        <translation>Minimizar lapela</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="142"/>
        <source>Restore minimized windows to current workspace</source>
        <translation>Restaurar as lapelas minimizadas no escritorio actual</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="149"/>
        <source>Draw window frame when hovering over a button</source>
        <translation>Deseñar caixiña da lapela ao pasar sobre un botón</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="156"/>
        <source>Switch windows using the mouse wheel</source>
        <translation>Cambiar de lapela coa roda do rato</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="166"/>
        <source>Filtering</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="172"/>
        <source>Show windows from all workspaces or viewports</source>
        <translation>AMosar lapelas de todas as áreas de traballo ou lapelas embebidas</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="179"/>
        <source>Show only minimized windows</source>
        <translation>Amosar só lapelas minimizadas</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="186"/>
        <source>Show windows from all monitors</source>
        <translation>Amosar lapelas de todos os monitores</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="210"/>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
</context>
<context>
    <name>xfwm_compositor_settings</name>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="14"/>
        <source>Dialog</source>
        <translation>Caixa de diálogo</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="23"/>
        <source>Feature Settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="29"/>
        <source>Display fullscreen overlay windows directly</source>
        <translation>Exhibir directamente as lapelas de sobreposición da pantalla interna</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="36"/>
        <source>Synchronize drawing to vertical blank</source>
        <translation>Sincronizar o deseño co trazo en branco vertical</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="43"/>
        <source>Show windows preview in place of icons when cycling</source>
        <translation>Ao percorrer as lapelas amosar a previsualización en vez das iconas</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="50"/>
        <source>Show shadows under popup windows</source>
        <translation>Amosar sombreado nas lapelas emerxentes</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="57"/>
        <source>Show shadows under dock windows</source>
        <translation>Amosar sombreado nas lapelas en doca</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="64"/>
        <source>Show shadows under regular windows</source>
        <translation>Amosar sombreado nas lapelas normais</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="74"/>
        <source>Opacity Settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="80"/>
        <source>Window decorations</source>
        <translation>Moldura da lapela</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="103"/>
        <source>Inactive windows</source>
        <translation>Lapelas inactivas</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="126"/>
        <source>Windows during move</source>
        <translation>Ao mover </translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="149"/>
        <source>Windows during resize</source>
        <translation>Ao redimensionar</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="172"/>
        <source>Popup Windows</source>
        <translation>Lapelas emerxentes</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="205"/>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.cpp" line="25"/>
        <source>Xfwm Compositor Settings</source>
        <translation>Configuración do compositor do Xfwm</translation>
    </message>
</context>
</TS>